@@ -1,10 +1,18 @@
 package Yote::SimpleLRUCache;
 
+use strict;
+use warnings;
+no warnings 'uninitialized';
+
+use vars qw($VERSION);
+
+$VERSION = '0.01';
+
 sub new {
     my( $pkg, $size, $boxes ) = @_;
     my $class = ref( $pkg ) || $pkg;
-    $size ||= 500;
-    $boxes || 50;
+    $size  ||= 500;
+    $boxes ||= 50;
     my $self = {
 	size  => $size,
 	boxes => [map { {} } (1..$boxes)]
@@ -35,3 +43,34 @@ sub stow {
 1;
 
 __END__
+
+=head1 INIT METHODS
+
+=over 4
+
+=item fetch( id )
+
+Return the object by id if it is cached
+
+=item stow( id, obj )
+
+Store the object with the given id
+
+=item new
+
+Create new cache
+
+=back
+
+=head1 AUTHOR
+
+Eric Wolf
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (C) 2011 Eric Wolf
+
+This module is free software; it can be used under the same terms as perl
+itself.
+
+=cut
